( cd usr/lib ; rm -rf libwpd-0.8.so.8 )
( cd usr/lib ; ln -sf libwpd-0.8.so.8.0.2 libwpd-0.8.so.8 )
( cd usr/lib ; rm -rf libwpd-0.8.so )
( cd usr/lib ; ln -sf libwpd-0.8.so.8.0.2 libwpd-0.8.so )
( cd usr/lib ; rm -rf libwpd-stream-0.8.so )
( cd usr/lib ; ln -sf libwpd-stream-0.8.so.8.0.2 libwpd-stream-0.8.so )
( cd usr/lib ; rm -rf libwpd-stream-0.8.so.8 )
( cd usr/lib ; ln -sf libwpd-stream-0.8.so.8.0.2 libwpd-stream-0.8.so.8 )
